@@ -1,6 +1,6 @@
 // This contains all the C++ code that is needed by the sip module.
 //
-// Copyright (c) 2013 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
 //
 // This file is part of SIP.
 //
@@ -18,5 +18,5 @@
 // Set a C++ bool for the main C implementation of the module.
 extern "C" void sipSetBool(void *ptr, int val)
 {
-	*reinterpret_cast<bool *>(ptr) = val;
+	*reinterpret_cast<bool *>(ptr) = !!val;
 }
